@@ -223,12 +223,19 @@ class SQLExecute(object):
                 for row in rowset:
                     m_row = []
                     for column in row:
+                        print("CONTENT2 = [" + column + "]")
                         if str(type(column)).find('JDBCClobClient') != -1:
                             m_row.append(column.getSubString(1, int(self.options["CLOB_LONG"])))
                         elif str(type(column)).find("Float") != -1:
                             m_row.append(self.options["FLOAT_FORMAT"] % column)
                         elif str(type(column)).find("Double") != -1:
                             m_row.append(self.options["DOUBLE_FORMAT"] % column)
+                        elif str(type(column)).find('str') != -1:
+                            # 对于二进制数据，其末尾用0x00表示，这里进行截断
+                            m_0x00Start = column.find(chr(0))
+                            if m_0x00Start != -1:
+                                column = column[0:m_0x00Start]
+                            m_row.append(column)
                         else:
                             m_row.append(column)
                     m_row = tuple(m_row)
